Learn R Programming

rsurfer (version 0.2)

adni.mergewithfreesurferoutput: ADNI Merge With 'Freesurfer' Output

Description

Merges the (baseline) Diagnosis, Age, Gender and MMSE for ADNI subjects with the post-processed 'Freesurfer' data, note that the rownames of the input data frame must be the Subject IDs i.e. 141_S_4232 of the ADNI database

Usage

adni.mergewithfreesurferoutput(df)

Arguments

df

The data frame of data imported using fsimport()

Value

The input data frame merged with Age, Gender, Diagnosis and MMSE

Examples

Run this code
# NOT RUN {
setfshome("/Applications/freesurfer")
df <- fsimport.serialise("~/CADDementiaSubjects/", "~/CADSubjects.rds", verbose = T)
adni.setfiles("DXSUM_PDXCONV_ADNIALL.csv", "ADNIMERGE.csv")
df <- adni.mergewithfreesurferoutput(df)
# }

Run the code above in your browser using DataLab