Learn R Programming

rsurfer (version 0.2)

caddementia.setfiles: CAD Dementia Set Files

Description

Points to the location of the two files required to merged the Diagnosis, Age and Gender for CAD Dementia subjects with the post-processed CAD Dementia data

Usage

caddementia.setfiles(trainLocation, testLocation)

Arguments

trainLocation

The filepath to train.txt

testLocation

The filepath to test.txt caddementia.setfiles("train.txt","test.txt")

Details

Data can be accessed: https://caddementia.grand-challenge.org/