Learn R Programming

rsurfer (version 0.2)

eliminateabnormalities.cols: Eliminate Abnormal Columns

Description

Will remove columns from a data frame of data generated by 'Freesurfer' that are abnormal - columns where all values are zero

Usage

eliminateabnormalities.cols(data, verbose = T)

Arguments

data

The data frame to remove abnormal columns from

verbose

Whether to print a log of what was removed

Value

The data frame with abnormal columns removed

Examples

Run this code
# NOT RUN {
data <- generaterandomsubjects()
eliminateabnormalities.cols(data)
# }

Run the code above in your browser using DataLab