Learn R Programming

rsurfer (version 0.2)

extract.corticalthicknesses: Extract Cortical Thicknesses

Description

This command takes a data frame as input and extracts all the cortical thicknesses from this data frame and any other fields specified by the user. Note that the MRIs must be processed with the 'hippocampal-subfields' flag when 'Freesurfer' is invoked.

Usage

extract.corticalthicknesses(data, additionalFields = c())

Arguments

data

The subject data to extract from

additionalFields

Any additional fields to extract data from

Value

The cortical thicknesses

Examples

Run this code
# NOT RUN {
data <- generaterandomsubjects()
extract.corticalthicknesses(data)
# }

Run the code above in your browser using DataLab