powered by
This command takes a data frame as input and extracts all the cortical volumes from this data frame and any other fields specified by the user. Note that the MRIs must be processed with the 'hippocampal-subfields' flag when 'Freesurfer' is invoked.
extract.corticalvolumes(data, additionalFields = c())
The subject data to extract from
Any additional fields to extract data from
The cortical volumes
# NOT RUN { data <- generaterandomsubjects() extract.corticalvolumes(data) # }
Run the code above in your browser using DataLab