Learn R Programming

rsurfer (version 0.2)

extract.hippocampalvolumes: Extract Hippocampal Volumes

Description

This command takes a data frame as input and extracts all the hippocampal volumes from this data frame and any other fields specified by the user. Note that the MRIs must be processed with the 'hippocampal-subfields' flag when 'Freesurfer' is invoked.

Usage

extract.hippocampalvolumes(data, additionalFields = c())

Arguments

data

The subject data to extract from

additionalFields

Any additional fields to extract data from

Value

The hippocampal volumes

Examples

Run this code
# NOT RUN {
data <- generaterandomsubjects()
extract.hippocampalvolumes(data)
# }

Run the code above in your browser using DataLab