Learn R Programming

rsurfer (version 0.2)

get.opposite.hemisphere.measurement: Get Opposite Hemisphere Measurement

Description

Given a left hemisphere measurement, will return the equivalent measure on the right hemisphere. If there is no equivalent feature, NULL will be returned

Usage

get.opposite.hemisphere.measurement(name, verbose = F, verbose_warn = F)

Arguments

name

The name of the feature to return the corresponding measurement of the opposite hemisphere of

verbose

If a corresponding feature doesn't exist, a message will be printed if this is true

verbose_warn

If a corresponding feature doesn't exist, a message will be printed as a warning if this is true

Value

Name of the feature on the other hemisphere (or NULL if the feature does not exist)

Examples

Run this code
# NOT RUN {
get.opposite.hemisphere.measurement("Right.vessel")
get.opposite.hemisphere.measurement("lhCortexVol")
# }

Run the code above in your browser using DataLab