Learn R Programming

rsurfer (version 0.2)

getnamesofareas: Get Names of Areas

Description

Gets the names of all the features that are areas

Usage

getnamesofareas(data = NULL, excludeFields = NULL)

Arguments

data

Your subject data frame, if you have removed any columns from your data frame, the function will only return the areas in this data frame. If this parameter is NULL then a new data frame will be randomly generated

excludeFields

A vector of areas names to exclude, to exclude nothing set this parameter to NULL

Value

A vector of the names of all the features which are areas

Examples

Run this code
# NOT RUN {
getnamesofareas()
getnamesofareas(NULL, NULL)
# }

Run the code above in your browser using DataLab