Learn R Programming

rsurfer (version 0.2)

searchforabnormalities.cols: Search For Abnormalities (Columns)

Description

Looks for columns which have been exported from 'Freesurfer' and may cause classification problems, for example, my personal abnormal columns are Left.WM.hypointensities, Right.WM.hypointensities, Left.non.WM.hypointensities, Right.WM.hypointensities only have values of zero

Usage

searchforabnormalities.cols(data, verbose = T)

Arguments

data

The data frame imported using fsimport

verbose

Whether the print debug information

Value

Indices of abnormal columns

Examples

Run this code
# NOT RUN {
data <- generaterandomsubjects()
searchforabnormalities.cols(data)
# }

Run the code above in your browser using DataLab