caddementia.setfiles: CAD Dementia Set Files
Description
Points to the location of the two files required to merged the Diagnosis, Age and Gender for CAD Dementia subjects with the post-processed CAD Dementia data
Usage
caddementia.setfiles(trainLocation, testLocation)
Arguments
trainLocation
The filepath to train.txt
testLocation
The filepath to test.txt
caddementia.setfiles("train.txt","test.txt")