powered by
Will remove columns from a data frame of data generated by 'Freesurfer' that are abnormal - columns where all values are zero
eliminateabnormalities.cols(data, verbose = T)
The data frame to remove abnormal columns from
Whether to print a log of what was removed
The data frame with abnormal columns removed
# NOT RUN { data <- generaterandomsubjects() eliminateabnormalities.cols(data) # }
Run the code above in your browser using DataLab